@@ -291,6 +291,13 @@ parametersCase3B = list(
 context("MultAdj - Success runs")
 
 test_that("Success run MultAdj with Case 1A", {  
+  
+    # Set the seed of R‘s random number generator.
+  # It also takes effect to Rcpp randome generation functions.
+  # https://stackoverflow.com/questions/60119621/get-the-same-sample-of-integers-from-rcpp-as-base-r
+  #RNGkind(sample.kind = "Rounding")
+  set.seed(5)
+
   # Run simulations
   results = MultAdj(parametersCase1A)
   expect_is(results, "MultAdjResults")
@@ -343,7 +350,7 @@ test_that("Success run MultAdj with Case 2A", {
   expect_length(sim_summary$power, 2)
   expect_equal(unname(sim_summary$power[1]), 0.4, tolerance = 0.4)
   expect_equal(unname(sim_summary$power[2]), 0.6, tolerance = 0.4)
-  expect_equal(unname(sim_summary$adj_power), 0.7, tolerance = 0.3)
+  expect_equal(unname(sim_summary$adj_power), 0.6, tolerance = 0.4)
 
   # Check for report generation
   GenerateReport(results, tempfile(fileext = ".docx"))
